pub struct BufferF32 {
pub buffer: Vec<f32>,
}Fields
buffer: Vec<f32>Trait Implementations
Sourceimpl BinRead for BufferF32
impl BinRead for BufferF32
Sourcetype Args = ()
type Args = ()
The type of arguments needed to be supplied in order to read this type, usually a tuple. Read more
Sourcefn read_options<R: Read + Seek>(
__binread_generated_var_reader: &mut R,
__binread_generated_var_options: &ReadOptions,
__binread_generated_var_arguments: Self::Args,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binread_generated_var_reader: &mut R, __binread_generated_var_options: &ReadOptions, __binread_generated_var_arguments: Self::Args, ) -> BinResult<Self>
Read the type from the reader
fn after_parse<R: Read + Seek>( &mut self, __binread_generated_var_reader: &mut R, __binread_generated_var_options: &ReadOptions, __binread_generated_var_arguments: Self::Args, ) -> BinResult<()>
Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Read the type from the reader while assuming no arguments have been passed Read more
impl StructuralPartialEq for BufferF32